==> haskell-colourista-0.1.0.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-GxK3aKYANxrEVZwOkFXtAP
key:                  colourista-0.1.0.2-GxK3aKYANxrEVZwOkFXtAP
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  8ed1fba063bab7ae8921693d0d9836d5
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-GxK3aKYANxrEVZwOkFXtAP
depends:
    ansi-terminal-0.11.4-EPVjDSBhsFM2RMZf92XUfK base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colourista-0.1.0.2-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.2
visibility:           public
id:                   colourista-0.1.0.2-LEN8jBskIkH9buF3Ix7mVq
key:                  colourista-0.1.0.2-LEN8jBskIkH9buF3Ix7mVq
license:              MPL-2.0
copyright:            2020-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  1c6372378b94253eb4c07a002fb12032
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/colourista-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colourista
hs-libraries:         HScolourista-0.1.0.2-LEN8jBskIkH9buF3Ix7mVq
depends:
    ansi-terminal-0.11.5-XBGI19OWrE6RSltGekvjf base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
